@@ -89,11 +89,15 @@ xp_channel_id = 'child::cppa:ChannelId/text()'
 def channelidtext(actionbinding):
     return actionbinding.xpath(xp_channel_id, namespaces=NSMAP)[0]
 
+xp_payload_profile_id = 'child::cppa:PayloadProfileId/text()'
+def payload_profile_id_list(actionbinding):
+    return actionbinding.xpath(xp_payload_profile_id, namespaces=NSMAP)
+
 xp_payload_profile = 'child::cppa:PayloadProfile[@id="{}"]'
 def payload_profile(cpa, actionbinding):
-    payload_profile_id = actionbinding.get('payloadProfileId')
-    if payload_profile_id != None:
-        payload_profile_list = cpa.xpath(xp_payload_profile.format(payload_profile_id),
+    payload_profile_ids = payload_profile_id_list(actionbinding)
+    if payload_profile_ids != []:
+        payload_profile_list = cpa.xpath(xp_payload_profile.format(payload_profile_ids[0]),
                                          namespaces=NSMAP)
         if len(payload_profile_list) > 0:
             return payload_profile_list[0]
@@ -257,7 +261,7 @@ xp_encryption = 'child::cppa:Encryption'
 def encryption(security):
     return return_if_present_else_none(security, xp_encryption)
 
-xp_encryptionalgorithm = 'child::cppa:DataEncryption/cppa:EncryptionAlgorithm/text()'
+xp_encryptionalgorithm = 'child::cppa:EncryptionAlgorithm/text()'
 def encryptionalgorithm(security):
     return return_if_present_else_none(security, xp_encryptionalgorithm)
 
